@@ -111,6 +111,8 @@ namespace clx {
 			return *this;
 		}
 		
+		string_type str() const { return str_; }
+		
 		template <class Ch, class Tr>
 		friend std::basic_ostream<Ch, Tr>& operator<<(
 			std::basic_ostream<Ch, Tr>& sout, const basic_format<Ch, Tr>& f) {
@@ -149,7 +151,7 @@ namespace clx {
 		
 		void setopt(internal_stream& ss, const string_type& flag) {
 			bool lp = false;
-			for (const_iterator pos = flag.begin(); pos != flag.end(); pos++) {
+			for (const_iterator pos = flag.begin(); pos != flag.end(); ++pos) {
 				if (*pos == ctrl.lpos) {
 					lp = true;
 					ss << std::setfill(ctrl.ws);
@@ -172,14 +174,14 @@ namespace clx {
 		
 		void setwidth(internal_stream& ss, const_iterator& cur, const_iterator last) {
 			std::string digit;
-			for (; cur != last && isdigit(*cur); cur++) digit += *cur;
+			for (; cur != last && isdigit(*cur); ++cur) digit += *cur;
 			if (!digit.empty()) ss << std::setw(lexical_cast<int>(digit));
 			if (cur != last && *cur == ctrl.dot) this->setprecision(ss, ++cur, last);
 		}
 		
 		void setprecision(internal_stream& ss, const_iterator& cur, const_iterator last) {
 			std::string digit;
-			for (; cur != last && isdigit(*cur); cur++) digit += *cur;
+			for (; cur != last && isdigit(*cur); ++cur) digit += *cur;
 			if (!digit.empty()) ss << std::setprecision(lexical_cast<int>(digit));
 		}
 		
